#
# spec file for package libverto-libev
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define src_name libverto
Name:           libverto-libev
Version:        0.3.2
Release:        3.3
Summary:        Main loop abstraction library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/latchset/libverto
Source:         https://github.com/latchset/libverto/releases/download/%{version}/libverto-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libverto) = %{version}

%description
libverto provides a way for libraries to expose asynchronous
interfaces without having to choose a particular event loop,
offloading this decision to the end application which consumes the
library.

If you are packaging an application, not library, based on libverto,
you should depend either on a specific implementation module or you
can depend on the virtual provides 'libverto-module-base'. This will
ensure that you have at least one module installed that provides io,
timeout and signal functionality. Currently glib is the only module
that does not provide these three because it lacks signal. However,
glib will support signal in the future.

%package        -n %{src_name}-libev%{sover}
Summary:        Backend module for libverto -- libev%{sover}
Group:          Development/Libraries/C and C++
Requires:       libverto%{sover} = %{version}
Provides:       %{src_name}-module-base = %{version}

%description    -n %{src_name}-libev%{sover}
Module for libverto which provides integration with libev.

This package provides libverto-module-base since it supports io,
timeout and signal.

%package        -n %{src_name}-libev-devel
Summary:        Development files for libverto-libev%{sover}
Group:          Development/Libraries/C and C++
Requires:       %{src_name}-devel%{?_isa} = %{version}
Requires:       %{src_name}-libev%{sover}%{?_isa} = %{version}

%description    -n %{src_name}-libev-devel
The libverto-libev-devel package contains libraries and header
files for developing applications that use libverto-libev.

%prep
%setup -q -n %{src_name}-%{version}

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -name '*.so.*T' -delete

# stuff in libverto already
rm -rf %{buildroot}/%{_includedir}/verto-module.h %{buildroot}/%{_includedir}/verto.h
rm -rf %{buildroot}/%{_libdir}/%{src_name}.so*
rm -rf %{buildroot}/%{_libdir}/pkgconfig/%{src_name}.pc

%post -n %{src_name}-libev%{sover} -p /sbin/ldconfig
%postun -n %{src_name}-libev%{sover} -p /sbin/ldconfig

%files -n %{src_name}-libev%{sover}
%{_libdir}/%{src_name}-libev.so.*

%files -n %{src_name}-libev-devel
%{_includedir}/verto-libev.h
%{_libdir}/%{src_name}-libev.so
%{_libdir}/pkgconfig/%{src_name}-libev.pc

%changelog
* Thu Aug 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.1:
  * Fix rare leak of DSO in module_load
  * Turn off -Wcast-function-type
  * Work around libev not being c89-compliant
  * Minor release bumps for verto_cleanup()
  * Leak fixes
  * Enforce strict c89 compliance for portability
  * Many warning fixes
  * Fix memleak in libverto:vfree
  * Update mutex usage to improve debugging
  * Add verto_cleanup() to free loaded_modules
  * Make C99 requirement explicit
* Tue Jun  6 2017 hguo@suse.com
- There is no change made about the package itself, this is only
  copying over some changelog texts from SLE package:
- [fate#320326](https://fate.suse.com/320326)
* Mon May 16 2016 mlin@suse.com
- Split off libev, glib and tevent module to sub-package
* Mon Jun 22 2015 hguo@suse.com
- Remove irrelevant changelog entries from changelog file.
* Sat May 30 2015 sor.alexei@meowr.ru
- Add baselibs.conf to enable multilib.
- Spec cleanup.
* Fri May  8 2015 pth@suse.de
- Name shared library packages according to policy.
* Fri May  8 2015 hguo@suse.com
- Source extracted from Fedora 21 release SRPM, with minor adjustments.
